pyswarms.utils.environments package
====================================

.. automodule:: pyswarms.utils.environments

.. deprecated:: 0.2.1
   This module will be deprecated in the next release. Please use
   :mod:`pyswarms.utils.plotters` instead.

pyswarms.utils.environments.plot_environment module
----------------------------------------------------

.. automodule:: pyswarms.utils.environments.plot_environment
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__